<?php

class qtc_gallery {

	private static $instance;
	private $postmeta = array(
		array(
			"section" => "Photo Gallery",
			"id" => "photo_gallery",
			"type" => "select",
			"title" => "Photo Gallery Template",
			"description" => "Select gallery template for this photo gallery",
			"items" => array(
				"" => "Select Gallery Temaplate",
				"single-gallery-2-column-container" => "Gallery 2 Columns Contained",
				"single-gallery-3-column-container" => "Gallery 3 Columns Contained",
				"single-gallery-4-column-container" => "Gallery 4 Columns Contained",
				"single-gallery-2-columns" => "Gallery 2 Columns",
				"single-gallery-3-columns" => "Gallery 3 Columns",
				"single-gallery-4-columns" => "Gallery 4 Columns",
			) ),
	);

	public static function forge() {
		if ( !isset( self::$instance ) ) {
			$className = __CLASS__;
			self::$instance = new $className;
		}
		return self::$instance;
	}

	private function __construct() {
		add_action( 'plugins_loaded', array( &$this, 'qtc_load_textdomain' ) );
		add_action( 'wp_enqueue_scripts', array( &$this, 'qtc_print_scripts' ) );
		add_action( 'wp_enqueue_scripts', array( &$this, 'qtc_print_styles' ) );
		add_image_size( 'qtc_gallery_admin_thumb', '109', '109', true );
		add_image_size( 'qtc_gallery_thumb', '150', '150', true );
		add_shortcode( 'qtc_gallery', array( &$this, 'qtc_shortcode' ) );
		if ( is_admin() ) {
			add_action( 'admin_print_scripts-post.php', array( &$this, 'qtc_admin_print_scripts' ) );
			add_action( 'admin_print_scripts-post-new.php', array( &$this, 'qtc_admin_print_scripts' ) );
			add_action( 'admin_print_styles', array( &$this, 'qtc_admin_print_styles' ) );
			add_action( 'add_meta_boxes', array( &$this, 'qtc_add_meta_boxes' ) );
			add_action( 'admin_init', array( &$this, 'qtc_add_meta_boxes' ), 1 );
			add_action( 'save_post', array( &$this, 'qtc_save_post_meta' ), 9, 1 );
			add_action( 'wp_ajax_qtc_gallery_get_thumbnail', array( &$this, 'qtc_ajax_get_thumbnail' ) );
			add_action( 'wp_ajax_qtc_gallery_get_all_thumbnail', array( &$this, 'qtc_ajax_get_all_attachments' ) );
		}
	}

	public function qtc_print_scripts() {
		wp_enqueue_script( 'qtc_gallery-scripts', QTC_GALLERY_URL . 'assets/js/qtc-gallery.min.js', array() );
//      wp_enqueue_script('qtc_gallery-ilightbox-scripts', QTC_GALLERY_URL . 'assets/js/ilightbox.packed.js', array());
	}

	public function qtc_print_styles() {
		wp_enqueue_style( 'qtc_gallery-style', QTC_GALLERY_URL . 'assets/css/qtc-gallery.min.css' );
		wp_enqueue_style( 'qtc_gallery-ilightbox-style', QTC_GALLERY_URL . 'assets/css/ilightbox.css' );
	}

	public function qtc_load_textdomain() {
		load_plugin_textdomain( 'qtc-gallery-translation', FALSE, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	public function qtc_admin_print_styles() {
		wp_enqueue_style( 'qtc-gallery-style', QTC_GALLERY_URL . 'assets/css/qtc-gallery-admin.css', array() );
	}

	public function qtc_admin_print_scripts() {
		wp_enqueue_script( 'media-upload' );
		wp_enqueue_script( 'qtc-gallery-admin-script', QTC_GALLERY_URL . 'assets/js/qtc-gallery-admin.js', array( 'jquery' ) );
	}

	public function qtc_add_meta_boxes() {
		add_meta_box( 'qtc_gallery', __( 'Gallery Images', 'qtc-gallery-translation' ), array( &$this, 'qtc_inner_custom_box' ), 'photo-gallery', 'advanced', 'high' );
		add_meta_box( 'qtc_metabox_gallery', __( 'Gallery Options', 'qtc-gallery-translation' ), array( &$this, 'qtc_new_meta_box' ), 'photo-gallery', 'side', 'low' );
	}

	public function qtc_inner_custom_box( $post ) {
		$design = get_post_meta( $post->ID, 'qtc_gallery', true );
		wp_nonce_field( basename( __FILE__ ), 'qtc_gallery_nonce' );

		$upload_size_unit = $max_upload_size = wp_max_upload_size();
		$sizes = array( 'KB', 'MB', 'GB' );

		for ( $u = -1; $upload_size_unit > 1024 && $u < count( $sizes ) - 1; $u++ ) {
			$upload_size_unit /= 1024;
		}

		if ( $u < 0 ) {
			$upload_size_unit = 0;
			$u = 0;
		} else {
			$upload_size_unit = (int) $upload_size_unit;
		}

		$upload_action_url = admin_url( 'async-upload.php' );
		$post_params = array(
			"post_id" => $post->ID,
			"_wpnonce" => wp_create_nonce( 'media-form' ),
			"short" => "1",
		);

		$post_params = apply_filters( 'upload_post_params', $post_params );

		$plupload_init = array(
			'runtimes' => 'html5,silverlight,flash,html4',
			'browse_button' => 'qtc-plupload-browse-button',
			'file_data_name' => 'async-upload',
			'multiple_queues' => true,
			'max_file_size' => $max_upload_size . 'b',
			'url' => $upload_action_url,
			'flash_swf_url' => includes_url( 'js/plupload/plupload.flash.swf' ),
			'silverlight_xap_url' => includes_url( 'js/plupload/plupload.silverlight.xap' ),
			'filters' => array( array( 'title' => __( 'Allowed Files', 'photography-translation' ), 'extensions' => '*' ) ),
			'multipart' => true,
			'urlstream_upload' => true,
			'multipart_params' => $post_params
		);
		?>
		<script type="text/javascript">
		    var POST_ID = <?php echo $post->ID; ?>;
		    var QTCUploader = <?php echo json_encode( $plupload_init ) ?>;
		</script>
		<div class="qtc_gallery_spinner" id="qtc_gallery_spinner"></div>
		<div id="qtc_gallery_container" class="qtc_gallery_container">
			<ul id="qtc_gallery_thumbs" class="clearfix qtc_gallery_thumbs"><?php
				$design = (is_string( $design )) ? @unserialize( $design ) : $design;
				if ( is_array( $design ) && count( $design ) > 0 ) {
					foreach ( $design as $id ) {
						echo $this->qtc_admin_thumb( $id );
					}
				}
				?>
			</ul>
		</div>
		<input id="qtc_gallery_upload_button" data-uploader_title="Add Image" data-uploader_button_text="Select" style="margin-bottom:8px" class="button-primary button qtc_gallery_upload_button" type="button" value="<?php echo __( 'Add Image', 'qtc_gallery' ); ?>" rel="" />
		<input id="qtc_gallery_delete_all_button" class="button button-default qtc_gallery_delete_all_button" type="button" style="margin-bottom:8px" value="<?php echo __( 'Delete All Images', 'qtc_gallery' ); ?>" rel="" />
		<?php
	}

	public function qtc_new_meta_box() {
		global $post;
		$postmeta = $this->postmeta;

		if ( !isset( $_GET['post_type'] ) OR empty( $_GET['post_type'] ) ) {
			if ( isset( $_GET['post'] ) && !empty( $_GET['post'] ) ) {
				$post_obj = get_post( $_GET['post'] );
				$_GET['post_type'] = $post_obj->post_type;
			} else {
				$_GET['post_type'] = 'post';
			}
		}
		$meta_section = '';

		foreach ( $postmeta as $postmeta_key => $each_meta ) {

			$meta_id = $each_meta['id'];
			$meta_title = $each_meta['title'];
			$meta_description = $each_meta['description'];

			if ( isset( $postmeta['section'] ) ) {
				$meta_section = $postmeta['section'];
			}

			$meta_type = '';
			if ( isset( $each_meta['type'] ) ) {
				$meta_type = $each_meta['type'];
			}

			echo '<div id="post_option_' . strtolower( $each_meta['id'] ) . '">';
			echo "<br/>" . $meta_title;
			if ( $meta_type == 'select' ) {
				echo "<p><select name='$meta_id' id='$meta_id'>";

				if ( !empty( $each_meta['items'] ) ) {
					foreach ( $each_meta['items'] as $key => $item ) {
						echo '<option value="' . $key . '"';

						if ( $key == get_post_meta( $post->ID, $meta_id, true ) ) {
							echo ' selected ';
						}

						echo '>' . $item . '</option>';
					}
				}
				echo "</select>"
				. "</p>";
			}
			echo '</div> ';
		}
		echo '<br/>';
	}

	private function qtc_admin_thumb( $id ) {
		$image = wp_get_attachment_image_src( $id, 'thumbnail', true );
		?>
		<li>
			<a href="<?php echo admin_url( 'post.php?post=' . $id . '&action=edit' ); ?>" target="_blank">
				<img src="<?php echo $image[0]; ?>" width="<?php echo $image[1]; ?>" height="<?php echo $image[2]; ?>" />
			</a>
			<a href="#" class="qtc_gallery_remove"><?php echo __( 'Remove', 'qtc_gallery' ); ?></a>
			<input type="hidden" name="qtc_gallery_thumb[]" value="<?php echo $id; ?>" />
		</li>
		<?php
	}

	public function qtc_ajax_get_thumbnail() {
		header( 'Cache-Control: no-cache, must-revalidate' );
		echo $this->qtc_admin_thumb( $_POST['imageid'] );
		die;
	}

	public function qtc_ajax_get_all_attachments() {
		$post_id = $_POST['post_id'];
		$included = (isset( $_POST['included'] )) ? $_POST['included'] : array();

		$attachments = get_children( array(
			'post_parent' => $post_id,
			'post_type' => 'attachment',
			'numberposts' => -1,
			'order' => 'ASC',
			'post_mime_type' => 'image',
				)
		);
		header( 'Cache-Control: no-cache, must-revalidate' );
		header( 'Expires: Mon, 26 Jul 1997 05:00:00 GMT' );
		if ( count( $attachments ) > 0 ) {
			foreach ( $attachments as $a ) {
				if ( !in_array( $a->ID, $included ) ) {
					echo $this->qtc_admin_thumb( $a->ID );
				}
			}
		}
		die;
	}

	private function qtc_thumb( $id, $post_id ) {
		$info = get_posts( array( 'p' => $id, 'post_type' => 'attachment' ) );
		$url = wp_get_attachment_url( $id );
		$image = wp_get_attachment_image_src( $id );
		$title_string = '%title%';
		$alt = get_post_meta( $id, '_wp_attachment_image_alt', true );
		$data = array(
			'%title%' => $info[0]->post_title,
			'%alt%' => $alt,
			'%filename%' => basename( $url ),
			'%caption%' => $info[0]->post_excerpt,
			"\n" => ' - '
		);
		$title = str_replace( array_keys( $data ), $data, $title_string );
		return '<li><a href="' . $url . '" title="' . $title . '" rel="qtc_gallery_group_' . $post_id . '"><img src="' . $image[0] . '" width="' . $image[1] . '" height="' . $image[2] . '" alt="' . $info[0]->post_title . '" /></a></li>';
	}

	public function qtc_save_post_meta( $post_id ) {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return '';
		}
		if ( !isset( $_POST['qtc_gallery_nonce'] ) || !wp_verify_nonce( $_POST['qtc_gallery_nonce'], basename( __FILE__ ) ) )
			return (isset( $post_id )) ? $post_id : 0;

		$postmeta = $this->postmeta;

		$images = (isset( $_POST['qtc_gallery_thumb'] )) ? $_POST['qtc_gallery_thumb'] : array();

		$gallery = array();
		if ( count( $images ) > 0 ) {
			foreach ( $images as $i => $img ) {
				if ( is_numeric( $img ) )
					$gallery[] = $img;
			}
		}
		foreach ( $postmeta as $each_meta ) {
			if ( isset( $_POST[$each_meta['id']] ) && $_POST[$each_meta['id']] ) {
				if ( !get_post_meta( $post_id, $each_meta['id'] ) ) {
					add_post_meta( $post_id, $each_meta['id'], $_POST[$each_meta['id']] );
				} else {
					update_post_meta( $post_id, $each_meta['id'], $_POST[$each_meta['id']] );
				}
			}
		}
		update_post_meta( $post_id, 'qtc_gallery', $gallery );
		return $post_id;
	}

	private function qtc_design( $post_id = false ) {
		global $post;
		$post_id = (!$post_id) ? $post->ID : $post_id;
		$design = get_post_meta( $post_id, 'qtc_gallery_design', true );
		$design = (is_string( $design )) ? @unserialize( $design ) : $design;
		$html = '';

		if ( is_array( $design ) && count( $design ) > 0 ) {
			$html = '<div id="qtc_gallery_container"><ul id="qtc_gallery" class="clearfix">';
			foreach ( $design as $thumbid ) {
				$html .= $this->qtc_qtc_thumb( $thumbid, $post_id );
			}
			$html .= '</ul></div>';
		}

		return $html;
	}

	public function qtc_output_design( $content ) {
		if ( post_password_required() ) {
			return $content;
		}

		$append_design = 1;
		if ( !post_password_required() && $append_design == '1' && is_singular() ) {
			$content .= $this->qtc_design();
		}
		return $content;
	}

	public function qtc_shortcode( $atts ) {
		extract( shortcode_atts( array(
			'id' => false,
						), $atts ) );
		return $this->qtc_design( $id );
	}

}

$qtc_gallery = qtc_gallery::forge();
