<?php

/**
 * @author QTC Media
 * @since 1.0.0
 */
class QTCMetaOptions {

    public function __construct() {
        add_action('add_meta_boxes', array($this, 'sympathy_add_meta_boxes'));
        add_action('admin_enqueue_scripts', array($this, 'sympathy_admin_script_loader'));
        add_action('save_post', array($this, 'save_meta_boxes'));
    }

    /* add script */

    function sympathy_admin_script_loader() {
        global $pagenow;

        if (is_admin() && ( $pagenow == 'post-new.php' || $pagenow == 'post.php' )) {
            wp_enqueue_style('sympathy-css-metabox', SYMPATHY_PLUGIN_URL . '/meta-options/css/metabox.css');
            wp_enqueue_script('sympathy-js-metabox', SYMPATHY_PLUGIN_URL . '/meta-options/js/metabox.js', array('jquery'), true);
            wp_enqueue_script('js-upload', SYMPATHY_PLUGIN_URL . '/meta-options/js/upload.js', array('jquery'), true);
        }
    }

    /* add meta boxs */

    public function sympathy_add_meta_boxes() {
        $this->add_meta_box('sympathy_page_options', esc_html__('Option Page', 'sympathy'), 'page');
        $this->add_meta_box_post('sympathy_post_link', esc_html__('Link Settings', 'sympathy'), 'post');
        $this->add_meta_box_post('sympathy_post_quote', esc_html__('Quote Settings', 'sympathy'), 'post');
        $this->add_meta_box_post('sympathy_post_video', esc_html__('Video Settings', 'sympathy'), 'post');
    }

    public function add_meta_box_post($id, $label, $post_type) {
        add_meta_box(
                'sympathy_' . $id, $label, array($this, $id), $post_type
        );
    }

    public function add_meta_box($id, $label, $post_type, $context = 'advanced', $priority = 'default') {
        add_meta_box('_cms_' . $id, $label, array($this, $id), $post_type, $context, $priority);
    }

    /* --------------------- PAGE ---------------------- */

    function sympathy_page_options($post) {
        global $sympathy_smof_data;
        $column_footer = '';
        $meta_data = sympathy_option_meta_id($post->ID);
        /* @var $header_position type */
        if ($meta_data) {
            if (isset($meta_data->_qtc_footer_layout)) {
                $column_footer = $meta_data->_qtc_footer_layout;
            }
        }

        global $wp_registered_sidebars;
        $sidebar_options = array("" => "None");
        foreach ($wp_registered_sidebars as $sidebar) {
            $sidebar_options[$sidebar['id']] = $sidebar['name'];
        }
        ?>
        <div class="tab-container clearfix">
            <ul class='tabs-menu clearfix'>
                <li class="current"><a href="#tabs-1"><span class="dashicons dashicons-admin-generic"></span> <?php esc_html_e('HEADER', 'sympathy'); ?></a></li>
                <li><a href="#tabs-2"><span class="dashicons dashicons-screenoptions"></span> <?php esc_html_e('SIDEBAR', 'sympathy'); ?></a></li>
                <li><a href="#tabs-3"><span class="dashicons dashicons-editor-kitchensink"></span> <?php esc_html_e('FOOTER', 'sympathy'); ?></a></li>
            </ul>
            <div class='tab'>
                <div id="tabs-1" class="tab-content">
                    <?php
                    /* Header. */
                    sympathy_options(array(
                        'id' => 'header',
                        'label' => esc_html__('Custom Header', 'sympathy'),
                        'type' => 'switch',
                        'options' => array('on' => '1', 'off' => ''),
                        'follow' => array('1' => array('#page_header_enable'))
                    ));
                    ?>
                    <div id="page_header_enable">
                        <?php
                        sympathy_options(array(
                            'id' => 'custom_layout_header',
                            'label' => esc_html__('Custom Layout Header', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                            'follow' => array('1' => array('#custom_layout_header'))
                        ));
                        ?>
                        <div id="custom_layout_header">
                            <?php
                            sympathy_options(array(
                                'id' => 'layout_ct_header',
                                'label' => esc_html__('Layout', 'sympathy'),
                                'type' => 'imegesselect',
                                'options' => array(
                                    'default' => SYMPATHY_THEME_URI . '/images/header/layout-header-2.jpg',
                                    'header1' => SYMPATHY_THEME_URI . '/images/header/layout-header-default.jpg',
                                    'header2' => SYMPATHY_THEME_URI . '/images/header/layout-header-2.jpg',
                                    'header3' => SYMPATHY_THEME_URI . '/images/header/layout-header-3.jpg',
                                    'header4' => SYMPATHY_THEME_URI . '/images/header/header-v4.png',
                                    'header5' => SYMPATHY_THEME_URI . '/images/header/header-5.png',
                                    'header6' => SYMPATHY_THEME_URI . '/images/header/header-6.png',
                                )
                            ));
                            ?>
                        </div>
                        <?php
                        sympathy_options(array(
                            'id' => 'sympathy_tranparent_header',
                            'label' => esc_html__('Tranparent Header', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                        ));
                        sympathy_options(array(
                            'id' => 'custom_color',
                            'label' => esc_html__('Custom Color', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                            'follow' => array('1' => array('#page_custom_color_header'))
                        ));
                        ?>
                        <div id="page_custom_color_header">
                            <?php
                            sympathy_options(array(
                                'id' => 'background_color',
                                'label' => esc_html__('Background Header', 'sympathy'),
                                'type' => 'color',
                                'default' => '#ffffff',
                                'rgba' => true
                            ));
                            sympathy_options(array(
                                'id' => 'menu_color',
                                'label' => esc_html__('Color Menu Item', 'sympathy'),
                                'type' => 'color',
                                'default' => '#222222',
                                    //'rgba' => true
                            ));
                            ?>
                        </div>
                        <?php
                        sympathy_options(array(
                            'id' => 'custom_logo',
                            'label' => esc_html__('Custom Logo', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                            'follow' => array('1' => array('#custom_logo_page'))
                        ));
                        ?>
                        <div id="custom_logo_page">
                            <?php
                            sympathy_options(array(
                                'id' => 'header_logo_page',
                                'label' => esc_html__('Logo', 'sympathy'),
                                'type' => 'image',
                                'default' => ''
                            ));
                            ?>
                        </div>
                        <?php
                        sympathy_options(array(
                            'id' => 'sympathy_enable_page_title',
                            'label' => esc_html__('Hidden Page Title', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => '')
                        ));
                        
                        ?>
                        <?php
                        sympathy_options(array(
                            'id' => 'custom_bg_page_title',
                            'label' => esc_html__('Custom Backgroud Page Title', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                            'follow' => array('1' => array('#custom_bg_page_title'))
                        ));
                        ?>
                        <div id="custom_bg_page_title">
                            <?php
                            sympathy_options(array(
                                'id' => 'sympathy_bg_page_title',
                                'label' => esc_html__('Change Background', 'sympathy'),
                                'type' => 'image',
                                'default' => ''
                            ));
                            ?>
                        </div>
                    </div>

                </div>
                <div id="tabs-2" class="tab-content">
                    <?php
                    sympathy_options(array(
                        'id' => 'show_sidebar',
                        'label' => esc_html__('Show Sidebar', 'sympathy'),
                        'type' => 'switch',
                        'options' => array('on' => '1', 'off' => ''),
                        'follow' => array('1' => array('#show_sidebar_page_left'))
                    ));
                    ?>
                    <div id="show_sidebar_page_left">
                        <?php
                        sympathy_options(array(
                            'id' => 'cus_sidebar_page',
                            'label' => esc_html__('Select Sidebar', 'sympathy'),
                            'type' => 'select',
                            'options' => $sidebar_options,
                        ));
                        sympathy_options(array(
                            'id' => 'sympathy_show_sidebar',
                            'label' => esc_html__('Left - Default Right', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                        ));
                        ?>
                    </div>
                </div>
                <div id="tabs-3" class="tab-content">
                    <?php
                    /* Footer. */
                    sympathy_options(array(
                        'id' => 'footer',
                        'label' => esc_html__('Custom Footer', 'sympathy'),
                        'type' => 'switch',
                        'options' => array('on' => '1', 'off' => ''),
                        'follow' => array('1' => array('#page_footer_enable'))
                    ));
                    ?>
                    <div id="page_footer_enable">
                        <?php
                        $footer_column = isset($sympathy_smof_data['qtc_footer_columns']) ? $sympathy_smof_data['qtc_footer_columns'] : '3';
                        if ($footer_column > 0) {
                            $column = array('' => 'Default');
                            for ($i = 1; $i <= $footer_column; $i ++) {
                                $column[$i] = 'Column ' . $i;
                            }
                            sympathy_options(array(
                                'id' => 'footer_layout',
                                'label' => esc_html__('Select column footer', 'sympathy'),
                                'type' => 'select',
                                'options' => $column,
                            ));
                        }
                        ?>
                        <div class="footer_widget_1" style="<?php echo ( $column_footer < 1 ) ? 'display:none;' : ''; ?>">
                            <?php
                            sympathy_options(array(
                                'id' => 'footer_widget_1',
                                'label' => esc_html__('Select Footer 1', 'sympathy'),
                                'type' => 'select',
                                'options' => $sidebar_options,
                            ));
                            ?>
                        </div>
                        <div class="footer_widget_2" style="<?php echo ( $column_footer < 2 ) ? 'display:none;' : ''; ?>">
                            <?php
                            sympathy_options(array(
                                'id' => 'footer_widget_2',
                                'label' => esc_html__('Select Footer 2', 'sympathy'),
                                'type' => 'select',
                                'options' => $sidebar_options,
                            ));
                            ?>
                        </div>
                        <div class="footer_widget_3" style="<?php echo ( $column_footer < 3 ) ? 'display:none;' : ''; ?>">
                            <?php
                            sympathy_options(array(
                                'id' => 'footer_widget_3',
                                'label' => esc_html__('Select Footer 3', 'sympathy'),
                                'type' => 'select',
                                'options' => $sidebar_options,
                            ));
                            ?>
                        </div>
                        <div class="footer_widget_4" style="<?php echo ( $column_footer < 4 ) ? 'display:none;' : ''; ?>">
                            <?php
                            sympathy_options(array(
                                'id' => 'footer_widget_4',
                                'label' => esc_html__('Select Footer 4', 'sympathy'),
                                'type' => 'select',
                                'options' => $sidebar_options,
                            ));
                            ?>
                        </div>
                        <div class="footer_widget_5" style="<?php echo ( $column_footer < 5 ) ? 'display:none;' : ''; ?>">
                            <?php
                            sympathy_options(array(
                                'id' => 'footer_widget_5',
                                'label' => esc_html__('Select Footer 5', 'sympathy'),
                                'type' => 'select',
                                'options' => $sidebar_options,
                            ));
                            ?>
                        </div>
                        <?php
                        sympathy_options(array(
                            'id' => 'custom_color_footer',
                            'label' => esc_html__('Custom Color', 'sympathy'),
                            'type' => 'switch',
                            'options' => array('on' => '1', 'off' => ''),
                            'follow' => array('1' => array('#page_custom_color_footer'))
                        ));
                        ?>
                        <div id="page_custom_color_footer">
                            <?php
                            sympathy_options(array(
                                'id' => 'background_color_footer',
                                'label' => esc_html__('Background', 'sympathy'),
                                'type' => 'color',
                                'default' => '#ffffff',
                                'rgba' => true
                            ));
                            sympathy_options(array(
                                'id' => 'color_footer',
                                'label' => esc_html__('Footer Text Color', 'sympathy'),
                                'type' => 'color',
                                'default' => '#000000',
                                'rgba' => true
                            ));
                            ?>
                        </div>
                    </div>
                </div>

            </div>
        </div>
        <?php
    }

    public function sympathy_post_link() {
        global $post;
        $value = get_post_meta($post->ID, 'sympathy_post_link', true);
        ?>
        <div id="sympathy_metabox_field_post_link" class="sympathy_metabox_field">
            <label for="sympathy_post_link">
                <?php echo esc_html__('Link URL', 'sympathy') ?>
            </label>
            <div class="field">
                <input type="text" id="sympathy_post_link" name="sympathy_post_link" value="<?php echo esc_url($value); ?>"/>

                <p><?php echo esc_html__('Please input the URL for your link. http://www.youwebsite.com', 'sympathy') ?> </p>
            </div>
        </div>

        <?php
    }

    public function sympathy_text($id, $label, $default, $desc = '') {
        global $post;
        $value = get_post_meta($post->ID, 'sympathy_' . $id, true);
        if (!$value) {
            $value = $default;
        }
        $html = '';
        $html .= '<label for="sympathy_' . $id . '">';
        $html .= $label;
        $html .= '</label>';
        $html .= '<div class="field">';
        $html .= '<input type="text" id="sympathy_' . $id . '" name="sympathy_' . $id . '" value="' . $value . '" />';
        if ($desc) {
            $html .= '<p>' . $desc . '</p>';
        }
        $html .= '</div>';
        echo '<div id="sympathy_metabox_field_' . $id . '" class="sympathy_metabox_field">' . $html . '</div>';
    }

    public function sympathy_select($id, $label, $options, $defualt, $desc = '') {
        global $post;
        $html = '';
        $html .= '<label for="sympathy_' . $id . '">';
        $html .= $label;
        $html .= '</label>';
        $html .= '<div class="field">';
        $html .= '<select id="sympathy_' . $id . '" name="sympathy_' . $id . '">';
        $value = get_post_meta($post->ID, 'sympathy_' . $id, true);
        $defualt = $value == '' ? $defualt = 'global' : $value;

        foreach ($options as $key => $option) {
            $selected = $defualt === (string) $key ? 'selected="selected"' : null;
            $html .= '<option ' . $selected . 'value="' . $key . '">' . $option . '</option>';
        }
        $html .= '</select>';
        if ($desc) {
            $html .= '<p>' . $desc . '</p>';
        }
        $html .= '</div>';

        echo '<div id="sympathy_metabox_field_' . $id . '" class="sympathy_metabox_field">' . $html . '</div>';
    }

    public function sympathy_textarea($id, $label, $desc = '') {
        global $post;

        $html = '';
        $html .= '<label for="sympathy_' . $id . '">';
        $html .= $label;
        $html .= '</label>';
        $html .= '<div class="field">';
        $html .= '<textarea cols="30" rows="5" id="sympathy_' . $id . '" name="sympathy_' . $id . '">' . get_post_meta($post->ID, 'sympathy_' . $id, true) . '</textarea>';
        if ($desc) {
            $html .= '<p>' . $desc . '</p>';
        }
        $html .= '</div>';

        echo '<div id="sympathy_metabox_field_' . $id . '" class="sympathy_metabox_field">' . $html . '</div>';
    }

    public function sympathy_upload($id, $label, $desc = '') {
        global $post;
        $html = '';
        $html .= '<label for="sympathy_' . $id . '">';
        $html .= $label;
        $html .= '</label>';
        $html .= '<div class="field">';
        $html .= '<input name="sympathy_' . $id . '" class="upload_field" id="sympathy_' . $id . '" type="text" value="' . get_post_meta($post->ID, 'sympathy_' . $id, true) . '" />';
        $html .= '<input class="sympathy_upload_button button button-primary button-large" type="button" value="Browse" />';
        if ($desc) {
            $html .= '<p>' . $desc . '</p>';
        }
        $html .= '</div>';

        echo '<div id="sympathy_metabox_field_' . $id . '" class="sympathy_metabox_field">' . $html . '</div>';
    }

    public function sympathy_post_quote() {
        ?>
        <div id="sympathy-blog-metabox" class='sympathy_metabox'>
            <?php
            $this->sympathy_select('post_quote_type', 'Quote Content', array(
                '' => 'From Post',
                'custom' => 'Custom'
                    ), '', ''
            );
            ?>
            <div id="post_quote_custom">
                <?php
                $this->sympathy_textarea('post_quote', 'Content', esc_html__('Please type the text for your quote here.', 'sympathy')
                );
                $this->sympathy_text('post_author', 'Author', '', esc_html__('Please type the text for author quote here.', 'sympathy')
                );
                ?>
            </div>
        </div>
        <?php
    }

    public function sympathy_post_video() {
        global $post;
        $video_time_id = get_post_meta($post->ID, '_upload_video_id', true);
        ?>
        <div id="tb-blog-loading" class="tb_loading" style="display: block;">
            <div id="followingBallsG">
                <div id="followingBallsG_1" class="followingBallsG"></div>
                <div id="followingBallsG_2" class="followingBallsG"></div>
                <div id="followingBallsG_3" class="followingBallsG"></div>
                <div id="followingBallsG_4" class="followingBallsG"></div>
            </div>
        </div>
        <div class='sympathy_metabox' style="display: block;">
            <?php
            $this->sympathy_select('post_video_source', 'Select Source', array(
                'post' => 'From Post',
                'media' => 'From Media',
                'youtube' => 'Youtube',
                'vimeo' => 'Vimeo'
                    ), '', ''
            );
            ?>
            <br> <label><?php echo esc_html__('Enter time video', 'sympathy'); ?></label><br>
            <input type="text" id="upload_video_time" name="_upload_video_time" value="<?php echo esc_attr($video_time_id); ?>"/>
            <br>
            <div id="sympathy_video_setting">
                <?php
                $this->sympathy_select('post_video_type', 'Video Type', array(
                    'mp4' => 'MP4',
                    'webm' => 'WebM',
                    'ogg' => 'Ogg'
                        ), '', ''
                );
                $this->sympathy_upload('post_video_url', esc_html__('Video URL', 'sympathy'), esc_html__('Please upload the (MP4,WebM,Ogg) video file. You must include both formats.', 'sympathy')
                );
                $this->sympathy_upload('post_preview_image', esc_html__('Preview Image', 'sympathy'), esc_html__('Image should be at least 680px wide. Click the "Upload" button to begin uploading your image, followed by "Select File" once you have made your selection. Only applies to self hosted videos.', 'sympathy')
                );
                $this->sympathy_text('post_video_youtube', esc_html__('Youtube', 'sympathy'), esc_html__('Enter in a Youtube (http://youtu.be/ID)', 'sympathy')
                );
                $this->sympathy_text('post_video_vimeo', esc_html__('Vimeo', 'sympathy'), esc_html__('Enter in a Vimeo (http://vimeo.com/ID)', 'sympathy')
                );
                ?>
                <p class="sympathy_info">
                    <i class="dashicons dashicons-dashboard"></i><a href="<?php echo 'http://www.w3schools.com/html/html5_video.asp'; ?>"><?php echo esc_html__('Video Formats and Browser Support', 'sympathy'); ?></a>
                </p>
            </div>
        </div>
        <?php
    }

    public function save_meta_boxes($post_id) {
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return;
        }
        $sympathy_meta = array();
        foreach ($_POST as $key => $value) {
            $sympathy_meta[$key] = $value;
            if (strstr($key, 'sympathy_')) {
                update_post_meta($post_id, $key, $value);
            }
        }
    }

}

new QTCMetaOptions();
