<?php

// Exit if accessed directly
if (!defined('ABSPATH'))
    exit;

class SYMPATHY_StaticCss {

    public $scss;

    function __construct() {
        global $sympathy_smof_data;

        /* scss */
        $this->scss = new scssc();

        /* set paths scss */
        $this->scss->setImportPaths(SYMPATHY_THEME_DIR . '/assets/scss/');

        /* generate css over time */

        $this->generate_file();
    }

    /**
     * generate css file.
     */
    public function generate_file() {
        global $sympathy_smof_data, $wp_filesystem;
        /* ---------------------------------------------------------------------------
         * Add WP_Filesystem.
         * --------------------------------------------------------------------------- */
        if (!class_exists('WP_Filesystem')) {
            require_once ABSPATH . 'wp-admin/includes/file.php';
        }
        WP_Filesystem();

        if (!empty($sympathy_smof_data) && !empty($wp_filesystem)) {

            $options_scss = SYMPATHY_THEME_DIR . '/assets/scss/_options.scss';

            /* delete files options.scss */
            $wp_filesystem->delete($options_scss);

            /* write options to scss file */
            $wp_filesystem->put_contents($options_scss, $this->css_render(), FS_CHMOD_FILE); // Save it

            /* minimize CSS styles */
            $this->scss->setFormatter('scss_formatter_compressed');

            /* compile scss to css */
            $css = $this->scss_render();

            $file = "main.css";

            $file = SYMPATHY_THEME_DIR . '/assets/css/' . $file;

            /* delete files static.css */
            $wp_filesystem->delete($file);

            /* write static.css file */
            $wp_filesystem->put_contents($file, $css, FS_CHMOD_FILE); // Save it
        }
    }

    /**
     * scss compile
     */
    public function scss_render() {
        /* compile scss to css */
        return $this->scss->compile('@import "master.scss"');
    }

    /**
     * main css
     */
    public function css_render() {
        global $sympathy_smof_data;
        ob_start();

        if (!empty($sympathy_smof_data['qtc_primary_color'])) {
            echo '$primary-color:' . esc_attr($sympathy_smof_data['qtc_primary_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_link_color'])) {
            echo '$link-color:' . esc_attr($sympathy_smof_data['qtc_link_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_link_hover_color'])) {
            echo '$link-color-hover:' . esc_attr($sympathy_smof_data['qtc_link_hover_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_button_text_color'])) {
            echo '$btn-primary:' . esc_attr($sympathy_smof_data['qtc_button_text_color']) . ';';
        }

        //menu
        if (!empty($sympathy_smof_data['qtc_menu_fontsize_first_level'])) {
            echo '$menu-fontsize:' . esc_attr($sympathy_smof_data['qtc_menu_fontsize_first_level']) . ';';
        } else {
            echo '$menu-fontsize: 14px;';
        }
        if (!empty($sympathy_smof_data['qtc_menu_color'])) {
            echo '$menu-color:' . esc_attr($sympathy_smof_data['qtc_menu_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_menu_hover_color'])) {
            echo '$menu-hover-color:' . esc_attr($sympathy_smof_data['qtc_menu_hover_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_menu_background_hover_color'])) {
            echo '$menu-hover-bg-color:' . esc_attr($sympathy_smof_data['qtc_menu_background_hover_color']) . ';';
        } else {
            echo '$menu-hover-bg-color: transparent;';
        }
        if (!empty($sympathy_smof_data['qtc_menu_acti_color'])) {
            echo '$menu-acti-color:' . esc_attr($sympathy_smof_data['qtc_menu_acti_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_menu_background_acti_color'])) {
            echo '$menu-bg-acti:' . esc_attr($sympathy_smof_data['qtc_menu_background_acti_color']) . ';';
        } else {
            echo '$menu-bg-acti: transparent;';
        }
        if (!empty($sympathy_smof_data['qtc_submenu_color'])) {
            echo '$submenu-color:' . esc_attr($sympathy_smof_data['qtc_submenu_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_background_submenu'])) {
            echo '$submenu-bg:' . esc_attr($sympathy_smof_data['qtc_background_submenu']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_sub_menu_acti_color'])) {
            echo '$submenu-acti-color:' . esc_attr($sympathy_smof_data['qtc_sub_menu_acti_color']) . ';';
        }
        if (!empty($sympathy_smof_data['qtc_sub_menu_backgound_acti_color'])) {
            echo '$submenu-bg-acti:' . esc_attr($sympathy_smof_data['qtc_sub_menu_backgound_acti_color']) . ';';
        } else {
            echo '$submenu-bg-acti: transparent;';
        }
        if (isset($sympathy_smof_data['qtc_footer_top_bg_image']) && $sympathy_smof_data['qtc_footer_top_bg_image']) {
            echo '#footer .sympathy-footer-top{background:url(' . $sympathy_smof_data['qtc_footer_top_bg_image']['url'] . ');background-size: cover; background-repeat: no-repeat;}';
        }
        //header
        if (isset($sympathy_smof_data['qtc_color_header_sticky']) && $sympathy_smof_data['qtc_color_header_sticky']) {
            echo '$color_menu:' . esc_attr($sympathy_smof_data['qtc_color_header_sticky'], 'sympathy') . ';';
        }
        if (isset($sympathy_smof_data['qtc_background_header']) && $sympathy_smof_data['qtc_background_header']) {
            echo '$bg-header:' . esc_attr($sympathy_smof_data['qtc_background_header']) . ';';
        }
        //Background Button Color
        if (isset($sympathy_smof_data['qtc_button_text_color']) && $sympathy_smof_data['qtc_button_text_color']) {
            echo '$bg-button-color:' . esc_attr($sympathy_smof_data['qtc_button_text_color']) . ';';
        } elseif (isset($sympathy_smof_data['qtc_primary_color']) && $sympathy_smof_data['qtc_primary_color']) {
            echo '$bg-button-color:' . esc_attr($sympathy_smof_data['qtc_primary_color']) . ';';
        }
        //body font
        if (isset($sympathy_smof_data['qtc_body_font_options']) && $sympathy_smof_data['qtc_body_font_options']) {
            echo '$size-font-body:' . esc_attr($sympathy_smof_data['qtc_body_font_options']['font-size']) . ';';
        }
        //body font
        if (isset($sympathy_smof_data['qtc_body_font_options']) && $sympathy_smof_data['qtc_body_font_options']) {
            echo '$color-font-body:' . esc_attr($sympathy_smof_data['qtc_body_font_options']['color']) . ';';
        }
        //topbar
        if (isset($sympathy_smof_data['qtc_bg_topbar_color']) && $sympathy_smof_data['qtc_bg_topbar_color']) {
            echo '$bg_topbar:' . esc_attr($sympathy_smof_data['qtc_bg_topbar_color'], 'sympathy') . ';';
        }
        if (isset($sympathy_smof_data['qtc_menu_topbar_color']) && $sympathy_smof_data['qtc_menu_topbar_color']) {
            echo '$color_menu_topbar:' . esc_attr($sympathy_smof_data['qtc_menu_topbar_color'], 'sympathy') . ';';
        }
        if (isset($sympathy_smof_data['qtc_header_topbar_uppercase']) && $sympathy_smof_data['qtc_header_topbar_uppercase']) {
            echo '$menu_topbar_uppercase:' . esc_html('uppercase', 'sympathy') . ';';
        } else {
            echo '$menu_topbar_uppercase:' . esc_html('none', 'sympathy') . ';';
        }
        //footer
        if (isset($sympathy_smof_data['qtc_backgroud_socket']) && $sympathy_smof_data['qtc_backgroud_socket']) {
            echo '$bg_socket:' . esc_attr($sympathy_smof_data['qtc_backgroud_socket'], 'sympathy') . ';';
        }
        if (isset($sympathy_smof_data['qtc_color_socket']) && $sympathy_smof_data['qtc_color_socket']) {
            echo '$color_socket:' . esc_attr($sympathy_smof_data['qtc_color_socket'], 'sympathy') . ';';
        }
        if (isset($sympathy_smof_data['qtc_footer_padding']) && $sympathy_smof_data['qtc_footer_padding']) {
            echo '$padding_footer:' . esc_attr($sympathy_smof_data['qtc_footer_padding'], 'sympathy') . ';';
        }
        if (isset($sympathy_smof_data['qtc_color_footer']) && $sympathy_smof_data['qtc_color_footer']) {
            echo '$color_footer:' . esc_attr($sympathy_smof_data['qtc_color_footer'], 'sympathy') . ';';
        }
        
        
        return ob_get_clean();
    }

}

new SYMPATHY_StaticCss();
