<?php
/**
 * List View Single Event
 * This file contains one event in the list view
 *
 * Override this template in your own theme by creating a file at [your-theme]/tribe-events/list/single-event.php
 *
 * @version 4.5.6
 *
 */
if (!defined('ABSPATH')) {
    die('-1');
}

// Setup an array of venue details for use later in the template
$venue_details = tribe_get_venue_details();

// Venue
$has_venue_address = (!empty($venue_details['address']) ) ? ' location' : '';

// Organizer
$organizer = tribe_get_organizer();

$post_id = get_the_ID();
$thumb_id = get_post_thumbnail_id($post_id);
$alt = get_post_meta($thumb_id, '_wp_attachment_image_alt', true);
$url = wp_get_attachment_url($thumb_id);
$image = sympathy_image_resize($url, 555, 450, true);
?>
<div class="sympathy_event_featured_image">
    <a href="<?php echo esc_url(tribe_get_event_link()); ?>" title="<?php the_title_attribute() ?>" rel="bookmark">
        <!-- Event Image -->
        <div class="tribe-events-event-image">
            <?php
            if (!empty($image)) {
                ?>
                <img src="<?php echo esc_url($image); ?>" alt="<?php if (count($alt)) echo esc_attr($alt); ?>">
                <?php
            }else {
                ?>
                <img src="<?php echo esc_url($url); ?>" alt="<?php if (count($alt)) echo esc_attr($alt); ?>">
                <?php
            }
            ?>
            <div class="thumbnail-hoverlay sympathy-main-color-bg"></div>
            <div class="thumbnail-hoverlay-icon"><i class="fa fa-link"></i></div>
        </div>
    </a>
</div>
<div class="sympathy_event_content">
    <!-- Event Title -->
    <?php do_action('tribe_events_before_the_event_title') ?>
    <h2 class="tribe-events-list-event-title">
        <a class="tribe-event-url" href="<?php echo esc_url(tribe_get_event_link()); ?>" title="<?php the_title_attribute() ?>" rel="bookmark">
            <?php the_title() ?>
        </a>
    </h2>
    <?php do_action('tribe_events_after_the_event_title') ?>

    <!-- Event Meta -->
    <?php do_action('tribe_events_before_the_meta') ?>
    <div class="tribe-events-event-meta">
        <div class="author <?php echo esc_attr($has_venue_address); ?>">

            <!-- Schedule & Recurrence Details -->
            <div class="tribe-event-schedule-details">
                <i class="fa fa-calendar"></i>
                <?php echo tribe_events_event_schedule_details() ?>
            </div>

            <?php if ($venue_details) : ?>
                <!-- Venue Display Info -->
                <div class="tribe-events-venue-details">
                    <i class="fa fa-map-marker"></i>
                    <?php echo implode(', ', $venue_details); ?>
                    <?php
                    if (tribe_get_map_link()) {
                        echo tribe_get_map_link_html();
                    }
                    ?>
                </div> <!-- .tribe-events-venue-details -->
            <?php endif; ?>

        </div>
    </div><!-- .tribe-events-event-meta -->
    <?php do_action('tribe_events_after_the_meta') ?>
    
    <!-- Event Content -->
    <?php do_action('tribe_events_before_the_content'); ?>
    <div class="tribe-events-list-event-description tribe-events-content description entry-summary">
        <?php echo tribe_events_get_the_excerpt(null, wp_kses_allowed_html('post')); ?>
    </div><!-- .tribe-events-list-event-description -->
    <?php
    do_action('tribe_events_after_the_content');
    ?>
    <div class="event-list-footer">
        <!-- Event Cost -->
        <?php if (tribe_get_cost()) : ?>
            <div class="tribe-events-event-cost">
                <span class="ticket-cost"><?php echo tribe_get_cost(null, true); ?></span>
                <?php
                /**
                 * Runs after cost is displayed in list style views
                 *
                 * @since 4.5
                 */
                do_action('tribe_events_inside_cost')
                ?>
            </div>
        <?php endif; ?>
        <a href="<?php echo esc_url(tribe_get_event_link()); ?>" class="tribe-events-read-more" rel="bookmark"><?php esc_html_e('Find out more', 'sympathy') ?> &raquo;</a>
    </div>
</div>