<?php
/**
 * Single Event Meta (Details) Template
 *
 * Override this template in your own theme by creating a file at:
 * [your-theme]/tribe-events/modules/meta/details.php
 *
 * @package TribeEventsCalendar
 */
$time_format = get_option('time_format', Tribe__Date_Utils::TIMEFORMAT);
$time_range_separator = tribe_get_option('timeRangeSeparator', ' - ');

$start_datetime = tribe_get_start_date();
$start_date = tribe_get_start_date(null, false);
$start_time = tribe_get_start_date(null, false, $time_format);
$start_ts = tribe_get_start_date(null, false, Tribe__Date_Utils::DBDATEFORMAT);

$end_datetime = tribe_get_end_date();
$end_date = tribe_get_display_end_date(null, false);
$end_time = tribe_get_end_date(null, false, $time_format);
$end_ts = tribe_get_end_date(null, false, Tribe__Date_Utils::DBDATEFORMAT);

$time_formatted = null;
if ($start_time == $end_time) {
    $time_formatted = esc_html($start_time);
} else {
    $time_formatted = esc_html($start_time . $time_range_separator . $end_time);
}

$event_id = Tribe__Main::post_id_helper();

/**
 * Returns a formatted time for a single event
 *
 * @var string Formatted time string
 * @var int Event post id
 */
$time_formatted = apply_filters('tribe_events_single_event_time_formatted', $time_formatted, $event_id);

/**
 * Returns the title of the "Time" section of event details
 *
 * @var string Time title
 * @var int Event post id
 */
$time_title = apply_filters('tribe_events_single_event_time_title', __('Time:', 'sympathy'), $event_id);

$cost = tribe_get_formatted_cost();
$website = tribe_get_event_website_link();
?>

<div class="spt-events-meta-group spt-events-meta-group-details">
    <h3 class="spt-events-single-title"> <?php esc_html_e('Details', 'sympathy') ?> </h3>
    <ul class="spt-list-data">

        <?php
        do_action('tribe_events_single_meta_details_section_start');

// All day (multiday) events
        if (tribe_event_is_all_day() && tribe_event_is_multiday()) :
            ?>
            <li>
                <label> <?php esc_html_e('Start:', 'sympathy') ?> </label>
                <span>
                    <?php esc_attr($start_date) ?>
                </span>
            </li>
            <li>
                <label> <?php esc_html_e('End:', 'sympathy') ?> </label>
                <span>
                    <?php esc_attr($end_date) ?>
                </span>
            </li>
            <?php
// All day (single day) events
        elseif (tribe_event_is_all_day()):
            ?>
            <li>
                <label> <?php esc_html_e('Date:', 'sympathy') ?> </label>
                <span>
                    <?php esc_attr($start_date) ?>
                </span>
            </li>
            <?php
// Multiday events
        elseif (tribe_event_is_multiday()) :
            ?>
            <li>
                <label> <?php esc_html_e('Start:', 'sympathy') ?> </label>
                <span>
                    <?php esc_attr($start_datetime) ?>
                </span>
            </li>
            <li>
                <label> <?php esc_html_e('End:', 'sympathy') ?> </label>
                <span>
                    <?php esc_attr($end_datetime) ?>
                </span>
            </li>
            <?php
// Single day events
        else :
            ?>
            <li>
                <label> <?php esc_html_e('Date:', 'sympathy') ?> </label>
                <span>
                    <?php esc_attr($start_date) ?>
                </span>
            </li>
            <label> <?php echo esc_html($time_title); ?> </label>
            <span>
                <?php echo esc_attr($time_formatted); ?>
            </span>

        <?php endif ?>

        <?php
        // Event Cost
        if (!empty($cost)) :
            ?>
            <li>
                <label> <?php esc_html_e('Cost:', 'sympathy') ?> </label>
                <span class="spt-events-event-cost sympathy-price"> <?php esc_attr($cost); ?> </span>
            </li>
        <?php endif ?>
        <li>
            <?php
            echo tribe_get_event_categories(
                    get_the_id(), array(
                'before' => '',
                'sep' => ', ',
                'after' => '',
                'label' => esc_html__('Category', 'sympathy'), // An appropriate plural/singular label will be provided
                'label_before' => '<label>',
                'label_after' => '</label>',
                'wrap_before' => '<span class="spt-events-event-categories">',
                'wrap_after' => '</span>',
                    )
            );
            ?>
        </li>
        <?php
        //echo tribe_meta_event_tags(sprintf(esc_html__('%s Tags:', 'sympathy'), tribe_get_event_label_singular()), ', ', false);
        $label = esc_html__('Tags:', 'sympathy');
        $separator = ', ';
        $echo = false;

        $tribe_ecp = Tribe__Events__Main::instance();
        $list = get_the_term_list(get_the_ID(), 'post_tag', '<li><label>' . $label . '</label><span class="spt-event-tags">', $separator, '</span></li>');
        $list = apply_filters('tribe_meta_event_tags', $list, $label, $separator, $echo);
        echo $list;
        ?>

        <?php
        // Event Website
        if (!empty($website)) :
            ?>
            <li>
                <label> <?php esc_html_e('Website:', 'sympathy') ?> </label>
                <span class="spt-events-event-url"> <?php echo esc_attr($website); ?> </span>
            </li>
        <?php endif ?>

        <?php do_action('tribe_events_single_meta_details_section_end') ?>
    </ul>
</div>
