<?php
/**
 * Single Event Template
 * A single event. This displays the event title, description, meta, and
 * optionally, the Google map for the event.
 *
 * Override this template in your own theme by creating a file at [your-theme]/tribe-events/single-event.php
 *
 * @package TribeEventsCalendar
 * @version  4.3
 *
 */
if (!defined('ABSPATH')) {
    die('-1');
}

$events_label_singular = tribe_get_event_label_singular();
$events_label_plural = tribe_get_event_label_plural();

$event_id = get_the_ID();

$venue_details = tribe_get_venue_details();
$venue_details2 = $venue_details['linked_name'];
?>

<div id="tribe-events-content" class="tribe-events-single">

    <p class="spt-events-back">
        <a href="<?php echo esc_url(tribe_get_events_link()); ?>"> <?php printf('&laquo; ' . esc_html_x('All %s', '%s Events plural label', 'sympathy'), $events_label_plural); ?></a>
    </p>

    <!-- Notices -->
    <?php tribe_the_notices() ?>


    <!-- #tribe-events-header -->

    <?php while (have_posts()) : the_post(); ?>
        <div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
            <!-- Event featured image, but exclude link -->
            <?php echo tribe_event_featured_image($event_id, 'full', false); ?>

            <header class="tribe-events-single-header">
                <?php the_title('<h1 class="tribe-events-single-event-title">', '</h1>'); ?>

                <div class="tribe-events-schedule events-single-header-meta tribe-clearfix">
                    <div class="sympathy-single-event-schedule">
                        <span class="event_schedule_detail">
                            <i class="fa fa-calendar-o"></i>
                            <?php echo tribe_events_event_schedule_details($event_id); ?>
                        </span>
                        <?php if ($venue_details2) : ?>
                            <span class="event_venue">
                            <i class="fa fa-map-marker" aria-hidden="true"></i>
                            <?php echo $venue_details2; ?>
                        </span>
                        <?php endif; ?>
                        
                        <?php if (tribe_get_cost()) : ?>
                            <span class="tribe-events-cost sympathy-price"><?php echo tribe_get_cost(null, true) ?></span>
                        <?php endif; ?>
                    </div>
                </div>
                <!-- Event header -->
                <div id="tribe-events-header" <?php tribe_events_the_header_attributes() ?>>
                    <!-- Navigation -->
                    <h3 class="tribe-events-visuallyhidden"><?php printf(esc_html__('%s Navigation', 'sympathy'), $events_label_singular); ?></h3>
                    <ul class="tribe-events-sub-nav">
                        <li class="tribe-events-nav-previous"><?php tribe_the_prev_event_link('<span>&laquo;</span> %title%') ?></li>
                        <li class="tribe-events-nav-next"><?php tribe_the_next_event_link('%title% <span>&raquo;</span>') ?></li>
                    </ul>
                    <!-- .tribe-events-sub-nav -->
                </div>
            </header>

            <!-- Event content -->
            <?php do_action('tribe_events_single_event_before_the_content') ?>
            <div class="tribe-events-single-event-description tribe-events-content">
                <?php the_content(); ?>
            </div>
            <!-- .tribe-events-single-event-description -->
            <?php do_action('tribe_events_single_event_after_the_content') ?>

            <!-- Event meta -->
            <?php do_action('tribe_events_single_event_before_the_meta') ?>
            <?php tribe_get_template_part('modules/meta'); ?>
            <?php do_action('tribe_events_single_event_after_the_meta') ?>
        </div> <!-- #post-x -->
        <?php if (get_post_type() == Tribe__Events__Main::POSTTYPE && tribe_get_option('showComments', false)) comments_template() ?>
    <?php endwhile; ?>

    <!-- Event footer -->
    <div id="tribe-events-footer">
        <!-- Navigation -->
        <h3 class="tribe-events-visuallyhidden"><?php printf(esc_html__('%s Navigation', 'sympathy'), $events_label_singular); ?></h3>
        <ul class="tribe-events-sub-nav">
            <li class="tribe-events-nav-previous"><?php tribe_the_prev_event_link('<span>&laquo;</span> %title%') ?></li>
            <li class="tribe-events-nav-next"><?php tribe_the_next_event_link('%title% <span>&raquo;</span>') ?></li>
        </ul>
        <!-- .tribe-events-sub-nav -->
    </div>
    <!-- #tribe-events-footer -->

</div><!-- #tribe-events-content -->
