<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */
 
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
global $sympathy_smof_data, $id_cat, $name_cat, $image, $alt;

get_header('shop');

$col_content = 'col-xs-12 col-sm-12 col-md-12 col-lg-12 woo-content';
$col_sidebar = $sympathy_sidebar_left = '';
if (is_active_sidebar('sympathy_shop_sidebar') && ($sympathy_smof_data['qtc_woo_layout'] != 'full' )) {

    $col_content = 'col-xs-12 col-sm-12 col-md-9 col-lg-9 woo-content';
    $col_sidebar = 'col-xs-12 col-sm-12 col-md-3 col-lg-3 woo-sidebar';
}
$sympathy_sidebar_woo = (!empty($sympathy_smof_data['qtc_woo_layout']) && $sympathy_smof_data['qtc_woo_layout'] == 'left') ? 'woo-sidebar-' . $sympathy_smof_data['qtc_woo_layout'] : 'woo-sidebar-right';

if ($sympathy_smof_data['qtc_woo_layout'] == 'left') {
    $sympathy_sidebar_left = 1;
}
if (isset($_GET['sidebar'])) {
    $sympathy_sidebar_woo = trim($_GET['sidebar']);
    $sympathy_sidebar_woo = $sympathy_sidebar_woo == 'woo-sidebar-left' ? $sympathy_sidebar_woo : 'woo-sidebar-right';
}
if (isset($_GET['sidebar'])) {
    $sympathy_sidebar_woo = trim($_GET['sidebar']);
    $col_content = $sympathy_sidebar_woo == 'full' ? 'col-sx-12 col-sm-12 col-md-12 col-lg-12 woo-content' : $col_content;
    $col_sidebar = $sympathy_sidebar_woo == 'full' ? '' : $col_sidebar;
}
$type_content = ( isset($_GET['view']) && ($_GET['view'] == 'list') ) ? 'woo-content-list' : 'woo-content-grid';

$sympathy_show_shop_title = isset($sympathy_smof_data['qtc_show_shop_title_bar']) ? $sympathy_smof_data['qtc_show_shop_title_bar'] : 1;
$sympathy_show_shop_breadcrumb = isset($sympathy_smof_data['qtc_show_page_breadcrumb_shop']) ? $sympathy_smof_data['qtc_show_page_breadcrumb_shop'] : 1;
sympathy_title_bar_shop($sympathy_show_shop_title, $sympathy_show_shop_breadcrumb);
?>
<div class="archive-products">
    <div class="container woocommerce_product_container">
        <div class="row <?php echo esc_attr($sympathy_sidebar_woo); ?>">
            <?php if ($col_sidebar && $sympathy_sidebar_left == '1') { ?>
                <div class="sympathy_sidebar <?php echo esc_attr($col_sidebar); ?>">
                    <div id="secondary" class="widget-area" role="complementary">
                        <div id="primary-sidebar" class="primary-sidebar widget-area" role="complementary">
                            <?php dynamic_sidebar('sympathy_shop_sidebar'); ?>
                        </div>
                    </div>
                </div>
            <?php } ?>
            <div class="<?php echo esc_attr($col_content) . " " . esc_attr($type_content); ?>">

                <?php do_action('woocommerce_archive_description'); ?>
                <?php if (have_posts()) : ?>
                    
                    <?php woocommerce_product_loop_start(); ?>

                    <?php woocommerce_product_subcategories(); ?>

                    <?php while (have_posts()) : the_post(); ?>
                        <?php
                        $post_id = get_the_ID();
                        $thumb_id = get_post_thumbnail_id($post_id);
                        $alt = get_post_meta($thumb_id, '_wp_attachment_image_alt', true);
                        $url = wp_get_attachment_url($thumb_id);
                        $image = sympathy_image_resize($url, 270, 277, true);                        
                        if (isset($_GET['view']) && ($_GET['view'] == 'list')) {
                            $image = sympathy_image_resize($url, 360, 360, true);
                        }
                        $term_list = wp_get_post_terms($post_id, 'product_cat');
                        $id_cat = 0;
                        $name_cat = "";
                        if (isset($term_list[0])) {
                            $id_cat = $term_list[0]->term_id;
                            $name_cat = $term_list[0]->name;
                        }

                        $layout_content = ( isset($_GET['view']) && ($_GET['view'] == 'list') ) ? 'productGrid' : 'product';
                        wc_get_template_part('content', $layout_content);
                        ?>

                    <?php endwhile; // end of the loop.  ?>

                    <?php woocommerce_product_loop_end(); ?>

                    <?php
                    /**
                     * woocommerce_after_shop_loop hook
                     *
                     * @hooked woocommerce_pagination - 10
                     */
                    if(!empty($sympathy_smof_data)){
                        if (isset($sympathy_smof_data['qtc_archive_show_pagination_shop']) && $sympathy_smof_data['qtc_archive_show_pagination_shop'] != ''){
                            do_action('woocommerce_after_shop_loop');
                        }
                    }else{
                        do_action('woocommerce_after_shop_loop');
                    }
                    ?>

                <?php elseif (!woocommerce_product_subcategories(array('before' => woocommerce_product_loop_start(false), 'after' => woocommerce_product_loop_end(false)))) : ?>

                    <?php wc_get_template('loop/no-products-found.php'); ?>

                <?php endif; ?>

            </div>
            <?php if ($col_sidebar && empty($sympathy_sidebar_left)) { ?>
                <div class="sympathy_sidebar <?php echo esc_attr($col_sidebar); ?>">
                    <div id="secondary" class="widget-area" role="complementary">
                        <div id="primary-sidebar" class="primary-sidebar widget-area" role="complementary">
                            <?php dynamic_sidebar('sympathy_shop_sidebar'); ?>
                        </div>
                    </div>
                </div>
            <?php } ?>
        </div>
    </div>
</div>
<?php
if (is_active_sidebar('sympathy_top_footer')) :
    ?>
    <div class="clearfix"></div>
    <div class="top_footer">
        <div class="container">
            <?php dynamic_sidebar('sympathy_top_footer'); ?>
        </div>
    </div>
    <?php
endif;
?>
<?php get_footer('shop'); ?>
