<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.1.0
 */

if (!defined('ABSPATH')) {
   exit; // Exit if accessed directly
}
global $sympathy_smof_data;

wc_print_notices();

do_action('woocommerce_before_cart');
?>
<ul class="procedure">
   <li class="shopping-cart active">
      <span class="title"><?php echo esc_html__('Shopping cart', 'sympathy'); ?></span> <span class="number">01</span>
   </li>
   <li class="check-out">
      <span class="title"><?php echo esc_html__('Check out', 'sympathy'); ?></span> <span class="number">02</span>
   </li>
   <li class="order-complated">
      <span class="title"><?php echo esc_html__('Order completed', 'sympathy'); ?></span> <span class="number">03</span>
   </li>
</ul>
<form class="woo-cart-form" action="<?php echo esc_url(WC()->cart->get_cart_url()); ?>" method="post">

   <?php do_action('woocommerce_before_cart_table'); ?>

   <div class="woo-cart-table">
      <table class="shop_table cart" cellspacing="1">
         <thead>
            <tr>
               <th class="woo-table-col-product"><?php echo esc_html__('Product', 'sympathy'); ?></th>
               <th class="woo-table-col-name"><?php echo esc_html__('Product name', 'sympathy'); ?></th>
               <th class="woo-table-col-price text-center"><?php echo esc_html__('Price', 'sympathy'); ?></th>
               <th class="woo-table-col-qty text-center"><?php echo esc_html__('Qty', 'sympathy'); ?></th>
               <th class="woo-table-col-total text-center"><?php echo esc_html__('Total', 'sympathy'); ?></th>
               <th class="product-remove text-right"><i class="fa fa-times" aria-hidden="true"></i></i></a>
               </th>
            </tr>
         </thead>
         <tbody>
            <?php do_action('woocommerce_before_cart_contents'); ?>

            <?php
            foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
               $_product = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);
               $product_id = apply_filters('woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key);

               if ($_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_cart_item_visible', true, $cart_item, $cart_item_key)) {
                  $product_permalink = apply_filters('woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink($cart_item) : '', $cart_item, $cart_item_key);
                  ?>
                  <tr class="woo-cart-item <?php echo esc_attr(apply_filters('woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key)); ?>">
 
                     <td class="woo-table-col-thumb">
                        <?php
                        $thumbnail = apply_filters('woocommerce_cart_item_thumbnail', $_product->get_image('custom-product-size'), $cart_item, $cart_item_key);

                        if (!$_product->is_visible()) {
                           echo do_shortcode($thumbnail);
                        } else {
                           printf('<a href="%s">%s</a>', $_product->get_permalink($cart_item), $thumbnail);
                        }
                        ?>
                     </td>

                     <td class="woo-table-col-title">
                        <?php
                        if (!$_product->is_visible()) {
                           echo apply_filters('woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key) . '&nbsp;';
                        } else {
                           echo apply_filters('woocommerce_cart_item_name', sprintf('<a href="%s">%s </a>', $_product->get_permalink($cart_item), $_product->get_title()), $cart_item, $cart_item_key);
                        }

                        // Meta data
                        echo WC()->cart->get_item_data($cart_item);

                        // Backorder notification
                        if ($_product->backorders_require_notification() && $_product->is_on_backorder($cart_item['quantity'])) {
                           echo '<p class="backorder_notification">' . esc_html__('Available on backorder', 'sympathy') . '</p>';
                        }
                        ?>
                     </td>

                     <td class="woo-table-col-price text-center">
                        <?php
                        echo apply_filters('woocommerce_cart_item_price', WC()->cart->get_product_price($_product), $cart_item, $cart_item_key);
                        ?>
                     </td>

                     <td class="woo-table-col-qty text-center">
                        <?php
                        if ($_product->is_sold_individually()) {
                           $product_quantity = sprintf('1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key);
                        } else {
                           $product_quantity = woocommerce_quantity_input(array(
                               'input_name' => "cart[{$cart_item_key}][qty]",
                               'input_value' => $cart_item['quantity'],
                               'max_value' => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
                               'min_value' => '0'
                                   ), $_product, false);
                        }

                        echo apply_filters('woocommerce_cart_item_quantity', $product_quantity, $cart_item_key);
                        ?>
                     </td>

                     <td class="text-center">
                        <?php
                        echo apply_filters('woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal($_product, $cart_item['quantity']), $cart_item, $cart_item_key);
                        ?>
                     </td>

                     <td class="woo-product-remove text-right">
                        <?php
                        echo apply_filters('woocommerce_cart_item_remove_link', sprintf('<a href="%s" class="remove" title="%s"><i class="fa fa-times" aria-hidden="true"></i></a>', esc_url(WC()->cart->get_remove_url($cart_item_key)), esc_html__('Remove this item', 'sympathy')), $cart_item_key);
                        ?>
                     </td>

                  </tr>
                  <?php
               }
            }

            do_action('woocommerce_cart_contents');
            ?>
            <tr class="woo-action-wrap">
               <td colspan="6" class="actions clearfix">
                  <div class="row">
                     <div class="col-md-6 col-sm-12 col-xs-12">
                        <div class="wc-proceed-to-checkout">

                           <p class="return-to-shop">
                              <a class="button wc-backward" href="<?php echo esc_url(apply_filters('woocommerce_return_to_shop_redirect', wc_get_page_permalink('shop'))); ?>"><?php echo esc_html__('Continue Shopping', 'sympathy') ?></a>
                           </p>

                        </div>
                     </div>
                     <div class="col-md-6 col-sm-12 col-xs-12">

                        <input type="submit" class="button" name="update_cart" value="<?php echo esc_html__('Update Cart', 'sympathy'); ?>"/>

                        <?php do_action('woocommerce_cart_actions'); ?>

                        <?php wp_nonce_field('woocommerce-cart'); ?>
                     </div>
                  </div>
               </td>
            </tr>

            <?php do_action('woocommerce_after_cart_contents'); ?>
         </tbody>
      </table>
   </div>
   <?php do_action('woocommerce_after_cart_table'); ?>

</form>
<div class="row col-action-shipping">
   <div class="col-md-4 col-sm-12 col-xs-12 col-shipping-cart">
      <div class="col-title-action"><?php echo esc_html__('estimate shipping and tax', 'sympathy'); ?></div>
      <?php if (WC()->cart->needs_shipping() && WC()->cart->show_shipping()) : ?>

         <?php do_action('woocommerce_cart_totals_before_shipping'); ?>

         <?php wc_cart_totals_shipping_html(); ?>

         <?php do_action('woocommerce_cart_totals_after_shipping'); ?>

      <?php elseif (WC()->cart->needs_shipping()) : ?>

         <div class="shipping">
            <div><?php woocommerce_shipping_calculator(); ?></div>
         </div>

      <?php endif; ?>

   </div>
   <div class="col-md-4 col-sm-12 col-xs-12">
      <div class="col-title-action"><?php echo esc_html__('Discount codes', 'sympathy'); ?></div>

      <?php if (WC()->cart->coupons_enabled()) { ?>
         <div class="coupon">

            <label for="coupon_code"><?php echo esc_html__('Coupon', 'sympathy'); ?>:</label>
            <input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php echo esc_html__('Coupon code', 'sympathy'); ?>"/>
            <input type="submit" class="button" name="apply_coupon" value="<?php echo esc_html__('Apply Coupon', 'sympathy'); ?>"/>

            <?php do_action('woocommerce_cart_coupon'); ?>

         </div>
      <?php } ?>
   </div>
   <div class="col-md-4 col-sm-12 col-xs-12">
      <div class="col-title-action"><?php echo esc_html__('CART TOTAL', 'sympathy'); ?></div>

      <div class="cart-collaterals">

         <?php woocommerce_cart_totals(); ?>

      </div>
   </div>
</div>

<?php do_action('woocommerce_after_cart'); ?>
