<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.3.0
 */ 
if (!defined('ABSPATH')) {
   exit;
}
?>
<ul class="procedure">
   <li class="shopping-cart">
      <span class="title"><?php echo esc_html__('Shopping cart', 'sympathy'); ?></span>
      <span class="number">01</span>
   </li>
   <li class="check-out active">
      <span class="title"><?php echo esc_html__('Check out', 'sympathy'); ?></span>
      <span class="number">02</span>
   </li>
   <li class="order-complated">
      <span class="title"><?php echo esc_html__('Order completed', 'sympathy'); ?></span>
      <span class="number">03</span>
   </li>
</ul>
<?php
wc_print_notices();

do_action('woocommerce_before_checkout_form', $checkout);

// If checkout registration is disabled and not logged in, the user cannot checkout
if (!$checkout->enable_signup && !$checkout->enable_guest_checkout && !is_user_logged_in()) {
   echo apply_filters('woocommerce_checkout_must_be_logged_in_message', esc_html__('You must be logged in to checkout.', 'sympathy'));
   return;
}

// filter hook for include new pages inside the payment method
$get_checkout_url = apply_filters('woocommerce_get_checkout_url', WC()->cart->get_checkout_url());
?>
<form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url($get_checkout_url); ?>" enctype="multipart/form-data">
   <div class="row">
      <div class="col-md-7 col-xs-12">
         <div class="woo-checkout-panel">
            <div class ="woo-panel-1">
               <?php if (sizeof($checkout->checkout_fields) > 0) : ?>
                  <?php do_action('woocommerce_checkout_before_customer_details'); ?>
                  <div class="col2-set" id="customer_details">
                     <div class="col2-set-1">
                        <?php do_action('woocommerce_checkout_billing'); ?>
                     </div>
                     <div class="col2-set-2">
                        <?php do_action('woocommerce_checkout_shipping'); ?>
                     </div>
                  </div>
                  <?php do_action('woocommerce_checkout_after_customer_details'); ?>
               <?php endif; ?>
            </div>
            <div class ="woo-panel-2">
               <div class="woo-checkout-information-2">
                  <div class="woocommerce-billing-fields ro-customer-info">
                     <div class="woo-title">
                        <h4><?php echo esc_html__('INFORMATION', 'sympathy'); ?></h4>
                        <span><a class="ro-edit-customer-info" href="#!"><?php echo esc_html__('Edit', 'sympathy'); ?></a></span>
                     </div>
                     <div class="woo-content">
                        <?php foreach ($checkout->checkout_fields['billing'] as $key => $field) : ?>
                           <?php
                           if ($checkout->get_value($key)) {
                              if ($key == 'billing_address_2') {
                                 echo '<div class="woo-info"><p><span> ' . esc_html__('ADDRESS-2', 'sympathy') . ': </span>' . $checkout->get_value($key) . '</p></div>';
                              } else {
                                 echo '<div class="woo-info"><p><span>' . $field['label'] . ': </span>' . $checkout->get_value($key) . '</p></div>';
                              }
                           }
                           ?>
                        <?php endforeach; ?>
                     </div>
                  </div>
               </div>
               <?php do_action('woocommerce_checkout_payment'); ?>
            </div>
         </div>
      </div>
      <div class="col-md-5 col-xs-12">
         <?php do_action('woocommerce_checkout_before_order_review'); ?>
         <div id="order_review" class="woocommerce-checkout-review-order">
            <?php do_action('woocommerce_order_review'); ?>
         </div>
         <?php do_action('woocommerce_checkout_after_order_review'); ?>
      </div>
   </div>
</form>

<?php do_action('woocommerce_after_checkout_form', $checkout); ?>
