<?php
/**
 * Thankyou page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/thankyou.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.0
 */
 
if (!defined('ABSPATH')) {
   exit; // Exit if accessed directly
}

if ($order) :
   ?>
   <ul class="procedure">
      <li class="shopping-cart">
         <span class="title"><?php echo esc_html__('Shopping cart', 'sympathy'); ?></span>
         <span class="number">01</span>
      </li>
      <li class="check-out">
         <span class="title"><?php echo esc_html__('Check out', 'sympathy'); ?></span>
         <span class="number">02</span>
      </li>
      <li class="order-complated active">
         <span class="title"><?php echo esc_html__('Order completed', 'sympathy'); ?></span>
         <span class="number">03</span>
      </li>
   </ul>
   <?php if ($order->has_status('failed')) : ?>
      <p><?php echo esc_html__('Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction.', 'sympathy'); ?></p>
      <p><?php
         if (is_user_logged_in())
            echo esc_html__('Please attempt your purchase again or go to your account page.', 'sympathy');
         else
            echo esc_html__('Please attempt your purchase again.', 'sympathy');
         ?></p>
      <p>
         <a href="<?php echo esc_url($order->get_checkout_payment_url()); ?>" class="button pay"><?php echo esc_html__('Pay', 'sympathy') ?></a>
         <?php if (is_user_logged_in()) : ?>
            <a href="<?php echo esc_url(wc_get_page_permalink('myaccount')); ?>" class="button pay"><?php echo esc_html__('My Account', 'sympathy'); ?></a>
         <?php endif; ?>
      </p>
   <?php else : ?>
      <p><?php echo apply_filters('woocommerce_thankyou_order_received_text', esc_html__('Thank you. Your order has been received.', 'sympathy'), $order); ?></p>

      <ul class="order_details">
         <li class="order">
            <?php echo esc_html__('Order Number:', 'sympathy'); ?>
            <strong><?php echo $order->get_order_number(); ?></strong>
         </li>
         <li class="date">
            <?php echo esc_html__('Date:', 'sympathy'); ?>
            <strong><?php echo date_i18n(get_option('date_format'), strtotime($order->order_date)); ?></strong>
         </li>
         <li class="total">
            <?php echo esc_html__('Total:', 'sympathy'); ?>
            <strong><?php echo $order->get_formatted_order_total(); ?></strong>
         </li>
         <?php if ($order->payment_method_title) : ?>
            <li class="method">
               <?php echo esc_html__('Payment Method:', 'sympathy'); ?>
               <strong><?php echo $order->payment_method_title; ?></strong>
            </li>
         <?php endif; ?>
      </ul>
      <div class="clear"></div>
   <?php endif; ?>
   <?php do_action('woocommerce_thankyou_' . $order->payment_method, $order->id); ?>
   <?php do_action('woocommerce_thankyou', $order->id); ?>
<?php else : ?>
   <p><?php echo apply_filters('woocommerce_thankyou_order_received_text', esc_html__('Thank you. Your order has been received.', 'sympathy'), null); ?></p>
<?php endif; ?>
