<?php
/**
 * Variable product add to cart
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/add-to-cart/variable.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */ 
if (!defined('ABSPATH'))
   exit; // Exit if accessed directly

global $woocommerce, $product, $post;
$attribute_keys = array_keys($attributes);
do_action('woocommerce_before_add_to_cart_form');
?>

<form class="variations_form cart" method="post" enctype='multipart/form-data' data-product_id="<?php echo absint($product->id); ?>" data-product_variations="<?php echo htmlspecialchars(json_encode($available_variations)) ?>">
   <?php do_action('woocommerce_before_variations_form'); ?>

   <?php if (empty($available_variations) && false !== $available_variations) : ?>
      <p class="stock out-of-stock"><?php echo esc_html__('This product is currently out of stock and unavailable.', 'sympathy'); ?></p>
   <?php else : ?>
      <table class="variations">
         <tbody>
            <?php foreach ($attributes as $attribute_name => $options) : ?>
               <tr>
                  <td class="label"><label for="<?php echo sanitize_title($attribute_name); ?>"><?php echo wc_attribute_label($attribute_name); ?></label></td>
                  <td class="value">
                     <?php
                     $selected = isset($_REQUEST['attribute_' . sanitize_title($attribute_name)]) ? wc_clean(urldecode($_REQUEST['attribute_' . sanitize_title($attribute_name)])) : $product->get_variation_default_attribute($attribute_name);
                     wc_dropdown_variation_attribute_options(array('options' => $options, 'attribute' => $attribute_name, 'product' => $product, 'selected' => $selected));
                     echo end($attribute_keys) === $attribute_name ? apply_filters('woocommerce_reset_variations_link', '<a class="reset_variations" href="#">' . __('Clear', 'sympathy') . '</a>') : '';
                     ?>
                  </td>
               </tr>
            <?php endforeach; ?>
         </tbody>
      </table>

      <?php do_action('woocommerce_before_add_to_cart_button'); ?>

      <div class="single_variation_wrap" style="display:none;">
         <?php do_action('woocommerce_before_single_variation'); ?>
         <div class="woo-price clearfix">
            <div>
               <p><?php echo esc_html__('Price:', 'sympathy'); ?></p>
            </div>
            <div class="single_variation"></div>
         </div>
         <div class="woo-quantity clearfix">
            <div>
               <p></p>
            </div>
            <div class="variations_button">
               <?php woocommerce_quantity_input(); ?>
               <div class="product_action">
                  <button type="submit" class="single_add_to_cart_button cart-button hi-icon"><?php echo esc_attr($product->single_add_to_cart_text()); ?></button>
               </div>
            </div>
         </div>

         <input type="hidden" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" />
         <input type="hidden" name="product_id" value="<?php echo esc_attr($post->ID); ?>" />
         <input type="hidden" name="variation_id" value="" />

         <?php do_action('woocommerce_after_single_variation'); ?>
      </div>

      <?php do_action('woocommerce_after_add_to_cart_button'); ?>

   <?php endif; ?>
   <?php do_action('woocommerce_after_variations_form'); ?>
</form>

<?php do_action('woocommerce_after_add_to_cart_form'); ?>
